import { Component, OnInit, Input, ViewChild, AfterContentInit } from '@angular/core';
import { MatTableDataSource, MatSort, PageEvent } from '@angular/material';
import { Router } from '@angular/router';
import { Store, select } from '@ngrx/store';
import { RPCError } from 'packages/core/rpc/error';
import { Notification } from '../../model';
import * as NotificationStore from '../../store/notification';
import { ReadAllByMemberSelector } from '../../store';
import { AuthSelector } from 'packages/member/store';
import { Member } from '../../../member/model';
import { PageParams, Page } from 'app/commons/model';

@Component({
  selector: 'of-notification',
  templateUrl: './notification.component.html',
  styleUrls: ['./notification.component.scss']
})
export class NotificationComponent implements OnInit, AfterContentInit {

  notification$ = this.store.pipe(select(ReadAllByMemberSelector.select('page')));

  displayedColumns = ['id', 'title', 'message', 'member'];
  dataSource: MatTableDataSource<Notification>;
  PAGE_SIZE = '10';
  totalLength = 0;

  constructor(
    private router: Router,
    private store: Store<NotificationStore.State>
  ) { }

  ngOnInit() {
    this.notification$.subscribe(
      (page: Page) => {
        if (page !== null) {
          this.totalLength = page.totalElements;
          this.dataSource = new MatTableDataSource(page.content);
        }
      },
      (error: RPCError) => {
        console.log(error.message);
      }
    );
  }

  ngAfterContentInit() {
    this.getNotifications(0);
  }

  getNotifications(pageIndex: number) {
    this.store.select(AuthSelector.select('member')).subscribe(
      (member: Member) => {
        const pageParams: PageParams = {
          pageNo: pageIndex + '',
          countPerPage: this.PAGE_SIZE,
          sortCol: 'id',
          sortDirection: 'descending'
        };
        this.store.dispatch(new NotificationStore.ReadAllByMember({ member, pageParams }));
      },
      (error) => {
        console.log(error);
      }
    );
  }

  handleRowClick(n: Notification) {
    this.router.navigate([n.url]);
  }

  handlePaging(e: PageEvent) {
    this.getNotifications(e.pageIndex);
  }
}
